@@ -287,7 +287,7 @@ void CDocument::create_new()
 
   textEdit->doc = this;
 
-  textEdit->currentLineColor =  QColor (hash_get_val (global_palette, 
+  textEdit->currentLineColor = QColor (hash_get_val (global_palette, 
                                              "cur_line_color", 
                                              "#EEF6FF")).darker (settings->value ("darker_val", 100).toInt()).name();
 
@@ -808,6 +808,9 @@ void CDocument::set_markup_mode()
   else
   if (e == "mediawiki")
     markup_mode = "MediaWiki";
+  else
+  if (e == "md" || e == "markdown")
+  markup_mode = "Markdown";  
 }
 
 
